# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EntityTagHeaderValue(Model):
    """EntityTagHeaderValue.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :ivar tag:
    :vartype tag: ~energycap.sdk.models.StringSegment
    :ivar is_weak:
    :vartype is_weak: bool
    """

    _validation = {
        'tag': {'readonly': True},
        'is_weak': {'readonly': True},
    }

    _attribute_map = {
        'tag': {'key': 'tag', 'type': 'StringSegment'},
        'is_weak': {'key': 'isWeak', 'type': 'bool'},
    }

    def __init__(self):
        super(EntityTagHeaderValue, self).__init__()
        self.tag = None
        self.is_weak = None



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillImportRequest(Model):
    """BillImportRequest.

    :param profile_code: optional - if not provided, we assume the data is in
     Advanced format
     A bill import profile code.
     Maps given data to Advanced format using the mappings defined by this
     profile
    :type profile_code: str
    :param file_name: FileName for the import file. Should include extension.
     Example: fileABC.csv
     Data contains the contents. The importer will save the under this file
     name.
     The extension allows the importer to read the data in the proper format
     (csv,xlsx,zip) <span class='property-internal'>Required</span>
    :type file_name: str
    :param batch_settings: If not using Workflow - Batch mode, this property
     is ignored
     Use this property to set batch mode and if creating new batch set
     batchCode
    :type batch_settings: ~energycap.sdk.models.BatchSettings
    :param data: The base64 encoded file. <span
     class='property-internal'>Required</span>
    :type data: str
    :param import_note: Optional note/comment.
    :type import_note: str
    :param save_as_resolved: Optional  property to indicate if failed audits
     automatically get marked as resolved
    :type save_as_resolved: bool
    :param comment: Optional comment to explain why the audit is being auto
     resolved
    :type comment: str
    """

    _validation = {
        'file_name': {'required': True},
        'data': {'required': True},
    }

    _attribute_map = {
        'profile_code': {'key': 'profileCode', 'type': 'str'},
        'file_name': {'key': 'fileName', 'type': 'str'},
        'batch_settings': {'key': 'batchSettings', 'type': 'BatchSettings'},
        'data': {'key': 'data', 'type': 'str'},
        'import_note': {'key': 'importNote', 'type': 'str'},
        'save_as_resolved': {'key': 'saveAsResolved', 'type': 'bool'},
        'comment': {'key': 'comment', 'type': 'str'},
    }

    def __init__(self, file_name, data, profile_code=None, batch_settings=None, import_note=None, save_as_resolved=None, comment=None):
        super(BillImportRequest, self).__init__()
        self.profile_code = profile_code
        self.file_name = file_name
        self.batch_settings = batch_settings
        self.data = data
        self.import_note = import_note
        self.save_as_resolved = save_as_resolved
        self.comment = comment



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FormTemplateRequest(Model):
    """FormTemplateRequest.

    :param template_id: The identifier for the template being assigned <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Required</span>
    :type template_id: int
    :param begin_date: The begin date of the template assignment <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Required</span>
    :type begin_date: datetime
    """

    _validation = {
        'template_id': {'required': True},
        'begin_date': {'required': True},
    }

    _attribute_map = {
        'template_id': {'key': 'templateId', 'type': 'int'},
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
    }

    def __init__(self, template_id, begin_date):
        super(FormTemplateRequest, self).__init__()
        self.template_id = template_id
        self.begin_date = begin_date



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillEntryBodyLineWithNounChild(Model):
    """BillEntryBodyLineWithNounChild.

    :param noun: The body line's noun
    :type noun: str
    :param value: The body line's numeric value
    :type value: float
    :param type: The body line's observation type
    :type type: str
    :param unit: The body line's unit
    :type unit: ~energycap.sdk.models.UnitChild
    """

    _attribute_map = {
        'noun': {'key': 'noun', 'type': 'str'},
        'value': {'key': 'value', 'type': 'float'},
        'type': {'key': 'type', 'type': 'str'},
        'unit': {'key': 'unit', 'type': 'UnitChild'},
    }

    def __init__(self, noun=None, value=None, type=None, unit=None):
        super(BillEntryBodyLineWithNounChild, self).__init__()
        self.noun = noun
        self.value = value
        self.type = type
        self.unit = unit



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class VendorTypeChild(Model):
    """VendorTypeChild.

    :param vendor_type_id: The vendor type identifier
    :type vendor_type_id: int
    :param vendor_type_code: The vendor type code
    :type vendor_type_code: str
    """

    _attribute_map = {
        'vendor_type_id': {'key': 'vendorTypeId', 'type': 'int'},
        'vendor_type_code': {'key': 'vendorTypeCode', 'type': 'str'},
    }

    def __init__(self, vendor_type_id=None, vendor_type_code=None):
        super(VendorTypeChild, self).__init__()
        self.vendor_type_id = vendor_type_id
        self.vendor_type_code = vendor_type_code



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FlagEventChild(Model):
    """FlagEventChild.

    :param flag_event_id: The flag event identifier
    :type flag_event_id: int
    :param created_by: The user that generated this flag event
    :type created_by: ~energycap.sdk.models.UserChild
    :param created_date: Date that this flag event was created
    :type created_date: datetime
    :param comment: Comment about the flag event
    :type comment: str
    :param description: Description of the flag event
    :type description: str
    :param flag_action: The type of action that caused this flag event
    :type flag_action: ~energycap.sdk.models.FlagActionChild
    """

    _attribute_map = {
        'flag_event_id': {'key': 'flagEventId', 'type': 'int'},
        'created_by': {'key': 'createdBy', 'type': 'UserChild'},
        'created_date': {'key': 'createdDate', 'type': 'iso-8601'},
        'comment': {'key': 'comment', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'flag_action': {'key': 'flagAction', 'type': 'FlagActionChild'},
    }

    def __init__(self, flag_event_id=None, created_by=None, created_date=None, comment=None, description=None, flag_action=None):
        super(FlagEventChild, self).__init__()
        self.flag_event_id = flag_event_id
        self.created_by = created_by
        self.created_date = created_date
        self.comment = comment
        self.description = description
        self.flag_action = flag_action



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarPlacePropertyCreate(Model):
    """EnergyStarPlacePropertyCreate.

    :param property_id: The property identifier
    :type property_id: int
    :param effective_date: The effective date
    :type effective_date: datetime
    :param value: The value of the property
    :type value: str
    """

    _attribute_map = {
        'property_id': {'key': 'propertyId', 'type': 'int'},
        'effective_date': {'key': 'effectiveDate', 'type': 'iso-8601'},
        'value': {'key': 'value', 'type': 'str'},
    }

    def __init__(self, property_id=None, effective_date=None, value=None):
        super(EnergyStarPlacePropertyCreate, self).__init__()
        self.property_id = property_id
        self.effective_date = effective_date
        self.value = value



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DynamicPercentageBillSplitResponse(Model):
    """Defines details for a dynamic percentage split of use, cost, or both based
    on the use or cost values of the meters in the destination meter group.

    :param destination_meter_group: Meter group to receive the results of the
     split bill.
    :type destination_meter_group: ~energycap.sdk.models.MeterGroupChild
    :param source_value_to_split: Value to distribute to the destination
     meters
     "use", "cost", or "useAndCost"
    :type source_value_to_split: str
    :param destination_share_value: Value to define how dynamic percentages
     are calculated.
     "use" or "cost"
    :type destination_share_value: str
    """

    _attribute_map = {
        'destination_meter_group': {'key': 'destinationMeterGroup', 'type': 'MeterGroupChild'},
        'source_value_to_split': {'key': 'sourceValueToSplit', 'type': 'str'},
        'destination_share_value': {'key': 'destinationShareValue', 'type': 'str'},
    }

    def __init__(self, destination_meter_group=None, source_value_to_split=None, destination_share_value=None):
        super(DynamicPercentageBillSplitResponse, self).__init__()
        self.destination_meter_group = destination_meter_group
        self.source_value_to_split = source_value_to_split
        self.destination_share_value = destination_share_value



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UserEditRequest(Model):
    """UserEditRequest.

    :param user_code: The user code. This is the user name that is used on
     sign-in <span class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type user_code: str
    :param full_name: The user's full name <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type full_name: str
    :param password: The user's password. Password is not changed if this
     field is empty <span class='property-internal'>Must be between 0 and 128
     characters</span>
    :type password: str
    :param email: The user's email address <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 128 characters</span>
    :type email: str
    :param cost_center_id: The topmost cost center the user can view <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Topmost (CostCenter)</span>
    :type cost_center_id: int
    :param place_id: The topmost place the user can view <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Topmost (Place)</span>
    :type place_id: int
    :param active_directory: Whether or not the user signs in using active
     directory. This is used for install client only <span
     class='property-internal'>Required</span>
    :type active_directory: bool
    :param active: Whether or not the user is active <span
     class='property-internal'>Required</span>
    :type active: bool
    :param password_expiration_interval: Days until the user's password
     expires <span class='property-internal'>Required</span>
    :type password_expiration_interval: int
    :param strong_password: Force the user's password to have a minimum of 8
     characters,
     containing at least 1 uppercase, 1 lowercase, 1 number, and 1 symbol <span
     class='property-internal'>Required</span>
    :type strong_password: bool
    :param force_password_change: Force the user to change their password on
     next login <span class='property-internal'>Required</span>
    :type force_password_change: bool
    :param user_role_id: The user's role <span
     class='property-internal'>Required</span>
    :type user_role_id: int
    :param max_approval_amount: The maximum bill amount (in dollars) the user
     can approve
     If not included, the user has no max limit
    :type max_approval_amount: int
    :param report_group_id: The user's report group. If not included, set to
     the default report group <span class='property-internal'>Required</span>
    :type report_group_id: int
    """

    _validation = {
        'user_code': {'required': True, 'max_length': 32, 'min_length': 0},
        'full_name': {'required': True, 'max_length': 32, 'min_length': 0},
        'password': {'max_length': 128, 'min_length': 0},
        'email': {'required': True, 'max_length': 128, 'min_length': 0},
        'cost_center_id': {'required': True},
        'place_id': {'required': True},
        'active_directory': {'required': True},
        'active': {'required': True},
        'password_expiration_interval': {'required': True},
        'strong_password': {'required': True},
        'force_password_change': {'required': True},
        'user_role_id': {'required': True},
        'max_approval_amount': {'required': True},
        'report_group_id': {'required': True},
    }

    _attribute_map = {
        'user_code': {'key': 'userCode', 'type': 'str'},
        'full_name': {'key': 'fullName', 'type': 'str'},
        'password': {'key': 'password', 'type': 'str'},
        'email': {'key': 'email', 'type': 'str'},
        'cost_center_id': {'key': 'costCenterId', 'type': 'int'},
        'place_id': {'key': 'placeId', 'type': 'int'},
        'active_directory': {'key': 'activeDirectory', 'type': 'bool'},
        'active': {'key': 'active', 'type': 'bool'},
        'password_expiration_interval': {'key': 'passwordExpirationInterval', 'type': 'int'},
        'strong_password': {'key': 'strongPassword', 'type': 'bool'},
        'force_password_change': {'key': 'forcePasswordChange', 'type': 'bool'},
        'user_role_id': {'key': 'userRoleId', 'type': 'int'},
        'max_approval_amount': {'key': 'maxApprovalAmount', 'type': 'int'},
        'report_group_id': {'key': 'reportGroupId', 'type': 'int'},
    }

    def __init__(self, user_code, full_name, email, cost_center_id, place_id, active_directory, active, password_expiration_interval, strong_password, force_password_change, user_role_id, max_approval_amount, report_group_id, password=None):
        super(UserEditRequest, self).__init__()
        self.user_code = user_code
        self.full_name = full_name
        self.password = password
        self.email = email
        self.cost_center_id = cost_center_id
        self.place_id = place_id
        self.active_directory = active_directory
        self.active = active
        self.password_expiration_interval = password_expiration_interval
        self.strong_password = strong_password
        self.force_password_change = force_password_change
        self.user_role_id = user_role_id
        self.max_approval_amount = max_approval_amount
        self.report_group_id = report_group_id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceEnergyStarPlaceTypeResponse(Model):
    """PlaceEnergyStarPlaceTypeResponse.

    :param energy_star_place_type_id: The energy star place type identifier
    :type energy_star_place_type_id: int
    :param place_id: The place identifier
    :type place_id: int
    :param place_type_code: The place type code
    :type place_type_code: str
    :param place_type_info: The place type info
    :type place_type_info: str
    :param energy_star_property_id: The place EnergyStar PlaceType Identifier
    :type energy_star_property_id: int
    :param primary_type: The primary type
    :type primary_type: bool
    :param energy_star_place_properties: An array of energy star place
     properties
    :type energy_star_place_properties:
     list[~energycap.sdk.models.EnergyStarPlacePropertyResponse]
    """

    _attribute_map = {
        'energy_star_place_type_id': {'key': 'energyStarPlaceTypeId', 'type': 'int'},
        'place_id': {'key': 'placeId', 'type': 'int'},
        'place_type_code': {'key': 'placeTypeCode', 'type': 'str'},
        'place_type_info': {'key': 'placeTypeInfo', 'type': 'str'},
        'energy_star_property_id': {'key': 'energyStarPropertyId', 'type': 'int'},
        'primary_type': {'key': 'primaryType', 'type': 'bool'},
        'energy_star_place_properties': {'key': 'energyStarPlaceProperties', 'type': '[EnergyStarPlacePropertyResponse]'},
    }

    def __init__(self, energy_star_place_type_id=None, place_id=None, place_type_code=None, place_type_info=None, energy_star_property_id=None, primary_type=None, energy_star_place_properties=None):
        super(PlaceEnergyStarPlaceTypeResponse, self).__init__()
        self.energy_star_place_type_id = energy_star_place_type_id
        self.place_id = place_id
        self.place_type_code = place_type_code
        self.place_type_info = place_type_info
        self.energy_star_property_id = energy_star_property_id
        self.primary_type = primary_type
        self.energy_star_place_properties = energy_star_place_properties



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestSavingsYearlyResponseCommodityData(Model):
    """PlaceDigestSavingsYearlyResponseCommodityData.

    :param commodity_code: The commodity code
    :type commodity_code: str
    :param commodity_info: The commodity info
    :type commodity_info: str
    :param commodity_id: The commodity identifier
    :type commodity_id: int
    :param all_time_batcc_common_use: Program to Date BATCC (Baseline Adjusted
     to Current Conditions) Common Use
    :type all_time_batcc_common_use: float
    :param all_time_common_use: Program to Date Common Use
    :type all_time_common_use: float
    :param all_time_savings_common_use: Program to Date Savings Common Use =
     allTimeBATCCCommonUse - allTimeCommonUse
    :type all_time_savings_common_use: float
    :param all_time_batcc_global_use: Program to Date BATCC (Baseline Adjusted
     to Current Conditions) Global Use
    :type all_time_batcc_global_use: float
    :param all_time_global_use: Program to Date Global Use
    :type all_time_global_use: float
    :param all_time_savings_global_use: Program to Date Savings Global Use =
     allTimeBATCCGlobalUse - allTimeGlobalUse
    :type all_time_savings_global_use: float
    :param all_time_batcc_total_cost: Program to Date BATCC (Baseline Adjusted
     to Current Conditions) Total Cost
    :type all_time_batcc_total_cost: float
    :param all_time_total_cost: Program to Date Total Cost
    :type all_time_total_cost: float
    :param all_time_savings_total_cost: Program to Date Savings Total Cost =
     allTimeBATCCTotalCost - allTimeTotalCost
    :type all_time_savings_total_cost: float
    :param cost_unit: The cost unit of measure
    :type cost_unit: ~energycap.sdk.models.UnitChild
    :param common_use_unit: The common use unit of measure
    :type common_use_unit: ~energycap.sdk.models.UnitChild
    :param results: An array of yearly data
    :type results:
     list[~energycap.sdk.models.PlaceDigestSavingsYearlyResponseCommodityDataCommodityResults]
    """

    _attribute_map = {
        'commodity_code': {'key': 'commodityCode', 'type': 'str'},
        'commodity_info': {'key': 'commodityInfo', 'type': 'str'},
        'commodity_id': {'key': 'commodityId', 'type': 'int'},
        'all_time_batcc_common_use': {'key': 'allTimeBATCCCommonUse', 'type': 'float'},
        'all_time_common_use': {'key': 'allTimeCommonUse', 'type': 'float'},
        'all_time_savings_common_use': {'key': 'allTimeSavingsCommonUse', 'type': 'float'},
        'all_time_batcc_global_use': {'key': 'allTimeBATCCGlobalUse', 'type': 'float'},
        'all_time_global_use': {'key': 'allTimeGlobalUse', 'type': 'float'},
        'all_time_savings_global_use': {'key': 'allTimeSavingsGlobalUse', 'type': 'float'},
        'all_time_batcc_total_cost': {'key': 'allTimeBATCCTotalCost', 'type': 'float'},
        'all_time_total_cost': {'key': 'allTimeTotalCost', 'type': 'float'},
        'all_time_savings_total_cost': {'key': 'allTimeSavingsTotalCost', 'type': 'float'},
        'cost_unit': {'key': 'costUnit', 'type': 'UnitChild'},
        'common_use_unit': {'key': 'commonUseUnit', 'type': 'UnitChild'},
        'results': {'key': 'results', 'type': '[PlaceDigestSavingsYearlyResponseCommodityDataCommodityResults]'},
    }

    def __init__(self, commodity_code=None, commodity_info=None, commodity_id=None, all_time_batcc_common_use=None, all_time_common_use=None, all_time_savings_common_use=None, all_time_batcc_global_use=None, all_time_global_use=None, all_time_savings_global_use=None, all_time_batcc_total_cost=None, all_time_total_cost=None, all_time_savings_total_cost=None, cost_unit=None, common_use_unit=None, results=None):
        super(PlaceDigestSavingsYearlyResponseCommodityData, self).__init__()
        self.commodity_code = commodity_code
        self.commodity_info = commodity_info
        self.commodity_id = commodity_id
        self.all_time_batcc_common_use = all_time_batcc_common_use
        self.all_time_common_use = all_time_common_use
        self.all_time_savings_common_use = all_time_savings_common_use
        self.all_time_batcc_global_use = all_time_batcc_global_use
        self.all_time_global_use = all_time_global_use
        self.all_time_savings_global_use = all_time_savings_global_use
        self.all_time_batcc_total_cost = all_time_batcc_total_cost
        self.all_time_total_cost = all_time_total_cost
        self.all_time_savings_total_cost = all_time_savings_total_cost
        self.cost_unit = cost_unit
        self.common_use_unit = common_use_unit
        self.results = results



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GenericBodylineRequest(Model):
    """Representation of a generic "empty" bodyline which is not associated with a
    specific bill or template.

    :param observation_type_id: The observation type
     For account body lines the observation type must be a charge type <span
     class='property-internal'>Required when CalculationType is set to Fixed,
     or Percentage</span>
    :type observation_type_id: int
    :param caption: The caption <span class='property-internal'>Must be
     between 0 and 32 characters</span> <span
     class='property-internal'>Required when CalculationType is set to Fixed,
     or Percentage, or Subtotal</span>
    :type caption: str
    :param calculation_type: The calculation type for the line item <span
     class='property-internal'>One of Fixed, Percentage, Subtotal </span>
    :type calculation_type: str
    :param value: The bodyline's value
     When CalculationType is Fixed.  Precision max is 2
     When CalculationType is Percentage.  Precision max is 8 <span
     class='property-internal'>Required when CalculationType is set to Fixed,
     or Percentage</span>
    :type value: float
    """

    _validation = {
        'caption': {'max_length': 32, 'min_length': 0},
    }

    _attribute_map = {
        'observation_type_id': {'key': 'observationTypeId', 'type': 'int'},
        'caption': {'key': 'caption', 'type': 'str'},
        'calculation_type': {'key': 'calculationType', 'type': 'str'},
        'value': {'key': 'value', 'type': 'float'},
    }

    def __init__(self, observation_type_id=None, caption=None, calculation_type=None, value=None):
        super(GenericBodylineRequest, self).__init__()
        self.observation_type_id = observation_type_id
        self.caption = caption
        self.calculation_type = calculation_type
        self.value = value



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RateVersionRequest(Model):
    """RateVersionRequest.

    :param effective_date: Effective date for the version <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span>
    :type effective_date: datetime
    :param note:  <span class='property-internal'>Must be between 0 and 255
     characters</span>
    :type note: str
    :param use_unit_cost: Unit cost for the use <span
     class='property-info'>Max precision of 8</span> <span
     class='property-info'>>NULL Valid</span>
    :type use_unit_cost: float
    :param use_unit_id: Use unit ID
    :type use_unit_id: int
    :param demand_unit_cost: Unit cost for the demand <span
     class='property-info'>Max precision of 8</span> <span
     class='property-info'>>NULL Valid</span>
    :type demand_unit_cost: float
    :param demand_unit_id: Demand unit ID
    :type demand_unit_id: int
    :param account_line_items: Cost bodylines for the account
    :type account_line_items:
     list[~energycap.sdk.models.GenericBodylineRequest]
    :param meter_line_items: Cost bodylines for the meter
    :type meter_line_items: list[~energycap.sdk.models.GenericBodylineRequest]
    """

    _validation = {
        'effective_date': {'required': True},
        'note': {'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'effective_date': {'key': 'effectiveDate', 'type': 'iso-8601'},
        'note': {'key': 'note', 'type': 'str'},
        'use_unit_cost': {'key': 'useUnitCost', 'type': 'float'},
        'use_unit_id': {'key': 'useUnitId', 'type': 'int'},
        'demand_unit_cost': {'key': 'demandUnitCost', 'type': 'float'},
        'demand_unit_id': {'key': 'demandUnitId', 'type': 'int'},
        'account_line_items': {'key': 'accountLineItems', 'type': '[GenericBodylineRequest]'},
        'meter_line_items': {'key': 'meterLineItems', 'type': '[GenericBodylineRequest]'},
    }

    def __init__(self, effective_date, note=None, use_unit_cost=None, use_unit_id=None, demand_unit_cost=None, demand_unit_id=None, account_line_items=None, meter_line_items=None):
        super(RateVersionRequest, self).__init__()
        self.effective_date = effective_date
        self.note = note
        self.use_unit_cost = use_unit_cost
        self.use_unit_id = use_unit_id
        self.demand_unit_cost = demand_unit_cost
        self.demand_unit_id = demand_unit_id
        self.account_line_items = account_line_items
        self.meter_line_items = meter_line_items



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterResponse(Model):
    """MeterResponse.

    :param meter_id: The identifier for the meter
    :type meter_id: int
    :param meter_code: The meter code
    :type meter_code: str
    :param meter_info: The meter info
    :type meter_info: str
    :param meter_type: The type of the meter
    :type meter_type: ~energycap.sdk.models.MeterTypeChild
    :param channels: An array of channels assigned to this meter
    :type channels: list[~energycap.sdk.models.ChannelChild]
    :param accounts:
    :type accounts: list[~energycap.sdk.models.MeterAccountChild]
    :param commodity: The meter's commodity
    :type commodity: ~energycap.sdk.models.CommodityChild
    :param place: The place this meter is assigned to
    :type place: ~energycap.sdk.models.PlaceChild
    :param address: The address of the meter
    :type address: ~energycap.sdk.models.AddressChild
    :param bill_entry_note: The bill entry note
    :type bill_entry_note: str
    :param include_in_energy_star: Indicates if the building is included in
     ENERGY STAR submissions
    :type include_in_energy_star: bool
    :param primary_use: The meter's primary use
    :type primary_use: ~energycap.sdk.models.PrimaryUseChild
    :param created_by: The user who created the meter
    :type created_by: ~energycap.sdk.models.UserChild
    :param created_date: The date and time the meter was created
    :type created_date: datetime
    :param modified_by: The most recent user who modified the meter
    :type modified_by: ~energycap.sdk.models.UserChild
    :param modified_date: The date and time of the most recent modification of
     the meter
    :type modified_date: datetime
    :param properties: An array of meter properties
    :type properties: dict[str, str]
    :param include_in_cost_avoidance: Indicates if the meter should be
     included in cost avoidance
    :type include_in_cost_avoidance: bool
    :param route: The meter's assigned route
    :type route: ~energycap.sdk.models.RouteChild
    :param meter_time_zone: The meter's time zone use
    :type meter_time_zone: ~energycap.sdk.models.TimeZoneChild
    :param active: Indicates whether the Meter is Active
    :type active: bool
    :param is_calculated_meter: Indicates whether the Meter is a calculated
     meter
    :type is_calculated_meter: bool
    :param is_split_parent_meter: Indicates whether the Meter is a parent of a
     split
    :type is_split_parent_meter: bool
    :param is_split_child_meter: Indicates whether the Meter is a child of a
     split
    :type is_split_child_meter: bool
    """

    _attribute_map = {
        'meter_id': {'key': 'meterId', 'type': 'int'},
        'meter_code': {'key': 'meterCode', 'type': 'str'},
        'meter_info': {'key': 'meterInfo', 'type': 'str'},
        'meter_type': {'key': 'meterType', 'type': 'MeterTypeChild'},
        'channels': {'key': 'channels', 'type': '[ChannelChild]'},
        'accounts': {'key': 'accounts', 'type': '[MeterAccountChild]'},
        'commodity': {'key': 'commodity', 'type': 'CommodityChild'},
        'place': {'key': 'place', 'type': 'PlaceChild'},
        'address': {'key': 'address', 'type': 'AddressChild'},
        'bill_entry_note': {'key': 'billEntryNote', 'type': 'str'},
        'include_in_energy_star': {'key': 'includeInEnergyStar', 'type': 'bool'},
        'primary_use': {'key': 'primaryUse', 'type': 'PrimaryUseChild'},
        'created_by': {'key': 'createdBy', 'type': 'UserChild'},
        'created_date': {'key': 'createdDate', 'type': 'iso-8601'},
        'modified_by': {'key': 'modifiedBy', 'type': 'UserChild'},
        'modified_date': {'key': 'modifiedDate', 'type': 'iso-8601'},
        'properties': {'key': 'properties', 'type': '{str}'},
        'include_in_cost_avoidance': {'key': 'includeInCostAvoidance', 'type': 'bool'},
        'route': {'key': 'route', 'type': 'RouteChild'},
        'meter_time_zone': {'key': 'meterTimeZone', 'type': 'TimeZoneChild'},
        'active': {'key': 'active', 'type': 'bool'},
        'is_calculated_meter': {'key': 'isCalculatedMeter', 'type': 'bool'},
        'is_split_parent_meter': {'key': 'isSplitParentMeter', 'type': 'bool'},
        'is_split_child_meter': {'key': 'isSplitChildMeter', 'type': 'bool'},
    }

    def __init__(self, meter_id=None, meter_code=None, meter_info=None, meter_type=None, channels=None, accounts=None, commodity=None, place=None, address=None, bill_entry_note=None, include_in_energy_star=None, primary_use=None, created_by=None, created_date=None, modified_by=None, modified_date=None, properties=None, include_in_cost_avoidance=None, route=None, meter_time_zone=None, active=None, is_calculated_meter=None, is_split_parent_meter=None, is_split_child_meter=None):
        super(MeterResponse, self).__init__()
        self.meter_id = meter_id
        self.meter_code = meter_code
        self.meter_info = meter_info
        self.meter_type = meter_type
        self.channels = channels
        self.accounts = accounts
        self.commodity = commodity
        self.place = place
        self.address = address
        self.bill_entry_note = bill_entry_note
        self.include_in_energy_star = include_in_energy_star
        self.primary_use = primary_use
        self.created_by = created_by
        self.created_date = created_date
        self.modified_by = modified_by
        self.modified_date = modified_date
        self.properties = properties
        self.include_in_cost_avoidance = include_in_cost_avoidance
        self.route = route
        self.meter_time_zone = meter_time_zone
        self.active = active
        self.is_calculated_meter = is_calculated_meter
        self.is_split_parent_meter = is_split_parent_meter
        self.is_split_child_meter = is_split_child_meter



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyProjectTypeCreate(Model):
    """EnergyProjectTypeCreate.

    :param energy_project_type_code: The energy project type code <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 16 characters</span>
    :type energy_project_type_code: str
    :param energy_project_type_info: The energy project type  info <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type energy_project_type_info: str
    """

    _validation = {
        'energy_project_type_code': {'required': True, 'max_length': 16, 'min_length': 0},
        'energy_project_type_info': {'required': True, 'max_length': 32, 'min_length': 0},
    }

    _attribute_map = {
        'energy_project_type_code': {'key': 'energyProjectTypeCode', 'type': 'str'},
        'energy_project_type_info': {'key': 'energyProjectTypeInfo', 'type': 'str'},
    }

    def __init__(self, energy_project_type_code, energy_project_type_info):
        super(EnergyProjectTypeCreate, self).__init__()
        self.energy_project_type_code = energy_project_type_code
        self.energy_project_type_info = energy_project_type_info



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ChannelChild(Model):
    """ChannelChild.

    :param channel_id:
    :type channel_id: int
    :param channel_code:
    :type channel_code: str
    :param interval:
    :type interval: int
    """

    _attribute_map = {
        'channel_id': {'key': 'channelId', 'type': 'int'},
        'channel_code': {'key': 'channelCode', 'type': 'str'},
        'interval': {'key': 'interval', 'type': 'int'},
    }

    def __init__(self, channel_id=None, channel_code=None, interval=None):
        super(ChannelChild, self).__init__()
        self.channel_id = channel_id
        self.channel_code = channel_code
        self.interval = interval



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterDigestNormalizedMonthlyResponse(Model):
    """MeterDigestNormalizedMonthlyResponse.

    :param meter_code: The meter code
    :type meter_code: str
    :param meter_info: The meter info
    :type meter_info: str
    :param meter_id: The meter identifier
    :type meter_id: int
    :param updated: The date and time the data was updated
    :type updated: datetime
    :param native_use_unit: The native use unit of measure
    :type native_use_unit: ~energycap.sdk.models.UnitChild
    :param native_demand_unit: The native demand unit of measure
    :type native_demand_unit: ~energycap.sdk.models.UnitChild
    :param common_use_unit: The common use unit of measure
    :type common_use_unit: ~energycap.sdk.models.UnitChild
    :param results: An array of monthly data
    :type results:
     list[~energycap.sdk.models.MeterDigestNormalizedMonthlyResponseResults]
    """

    _attribute_map = {
        'meter_code': {'key': 'meterCode', 'type': 'str'},
        'meter_info': {'key': 'meterInfo', 'type': 'str'},
        'meter_id': {'key': 'meterId', 'type': 'int'},
        'updated': {'key': 'updated', 'type': 'iso-8601'},
        'native_use_unit': {'key': 'nativeUseUnit', 'type': 'UnitChild'},
        'native_demand_unit': {'key': 'nativeDemandUnit', 'type': 'UnitChild'},
        'common_use_unit': {'key': 'commonUseUnit', 'type': 'UnitChild'},
        'results': {'key': 'results', 'type': '[MeterDigestNormalizedMonthlyResponseResults]'},
    }

    def __init__(self, meter_code=None, meter_info=None, meter_id=None, updated=None, native_use_unit=None, native_demand_unit=None, common_use_unit=None, results=None):
        super(MeterDigestNormalizedMonthlyResponse, self).__init__()
        self.meter_code = meter_code
        self.meter_info = meter_info
        self.meter_id = meter_id
        self.updated = updated
        self.native_use_unit = native_use_unit
        self.native_demand_unit = native_demand_unit
        self.common_use_unit = common_use_unit
        self.results = results



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TimeFormatResponse(Model):
    """TimeFormatResponse.

    :param display_name:
    :type display_name: str
    :param format_mask:
    :type format_mask: str
    """

    _attribute_map = {
        'display_name': {'key': 'displayName', 'type': 'str'},
        'format_mask': {'key': 'formatMask', 'type': 'str'},
    }

    def __init__(self, display_name=None, format_mask=None):
        super(TimeFormatResponse, self).__init__()
        self.display_name = display_name
        self.format_mask = format_mask



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WidgetEdit(Model):
    """WidgetEdit.

    :param specific_widget_id: Specific Widget identifier <span
     class='property-internal'>Required</span>
    :type specific_widget_id: int
    :param title: Personal Widget title <span class='property-internal'>Must
     be between 0 and 600 characters</span> <span
     class='property-internal'>Required</span>
    :type title: str
    :param row: Dashboard row
    :type row: int
    :param col: Dashboard column
    :type col: int
    :param height: Widget height
    :type height: int
    :param width: Widget width
    :type width: int
    :param filters: Widget filters
    :type filters: list[~energycap.sdk.models.FilterEdit]
    """

    _validation = {
        'specific_widget_id': {'required': True},
        'title': {'required': True, 'max_length': 600, 'min_length': 0},
    }

    _attribute_map = {
        'specific_widget_id': {'key': 'specificWidgetId', 'type': 'int'},
        'title': {'key': 'title', 'type': 'str'},
        'row': {'key': 'row', 'type': 'int'},
        'col': {'key': 'col', 'type': 'int'},
        'height': {'key': 'height', 'type': 'int'},
        'width': {'key': 'width', 'type': 'int'},
        'filters': {'key': 'filters', 'type': '[FilterEdit]'},
    }

    def __init__(self, specific_widget_id, title, row=None, col=None, height=None, width=None, filters=None):
        super(WidgetEdit, self).__init__()
        self.specific_widget_id = specific_widget_id
        self.title = title
        self.row = row
        self.col = col
        self.height = height
        self.width = width
        self.filters = filters



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillExport(Model):
    """BillExport.

    :param bill_ids:  <span class='property-internal'>Cannot be Empty</span>
     <span class='property-internal'>NULL Valid</span>
    :type bill_ids: list[int]
    :param export_mode:  <span class='property-internal'>Required</span> <span
     class='property-internal'>One of ap, gl </span>
    :type export_mode: str
    :param mark_as_exported:  <span class='property-internal'>Required</span>
    :type mark_as_exported: bool
    :param export_note: Optional note/comment.
    :type export_note: str
    """

    _validation = {
        'bill_ids': {'required': True},
        'export_mode': {'required': True},
        'mark_as_exported': {'required': True},
    }

    _attribute_map = {
        'bill_ids': {'key': 'billIds', 'type': '[int]'},
        'export_mode': {'key': 'exportMode', 'type': 'str'},
        'mark_as_exported': {'key': 'markAsExported', 'type': 'bool'},
        'export_note': {'key': 'exportNote', 'type': 'str'},
    }

    def __init__(self, bill_ids, export_mode, mark_as_exported, export_note=None):
        super(BillExport, self).__init__()
        self.bill_ids = bill_ids
        self.export_mode = export_mode
        self.mark_as_exported = mark_as_exported
        self.export_note = export_note



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterDigestGHGYearlyResponse(Model):
    """MeterDigestGHGYearlyResponse.

    :param meter_id: The meter identifier
    :type meter_id: int
    :param meter_code: The meter code
    :type meter_code: str
    :param meter_info: The meter info
    :type meter_info: str
    :param equivalent_co2_emissions_unit: The native use unit of measure
    :type equivalent_co2_emissions_unit: ~energycap.sdk.models.UnitChild
    :param ghg_scope: Greenhouse gas scope
    :type ghg_scope:
     ~energycap.sdk.models.MeterDigestGHGYearlyResponseGHGScope
    :param ghg_types: List of greenhouse gas types with use by year
    :type ghg_types:
     list[~energycap.sdk.models.MeterDigestGHGYearlyResponseGHGType]
    :param updated: The date and time the data was retrieved
    :type updated: datetime
    """

    _attribute_map = {
        'meter_id': {'key': 'meterId', 'type': 'int'},
        'meter_code': {'key': 'meterCode', 'type': 'str'},
        'meter_info': {'key': 'meterInfo', 'type': 'str'},
        'equivalent_co2_emissions_unit': {'key': 'equivalentCO2EmissionsUnit', 'type': 'UnitChild'},
        'ghg_scope': {'key': 'ghgScope', 'type': 'MeterDigestGHGYearlyResponseGHGScope'},
        'ghg_types': {'key': 'ghgTypes', 'type': '[MeterDigestGHGYearlyResponseGHGType]'},
        'updated': {'key': 'updated', 'type': 'iso-8601'},
    }

    def __init__(self, meter_id=None, meter_code=None, meter_info=None, equivalent_co2_emissions_unit=None, ghg_scope=None, ghg_types=None, updated=None):
        super(MeterDigestGHGYearlyResponse, self).__init__()
        self.meter_id = meter_id
        self.meter_code = meter_code
        self.meter_info = meter_info
        self.equivalent_co2_emissions_unit = equivalent_co2_emissions_unit
        self.ghg_scope = ghg_scope
        self.ghg_types = ghg_types
        self.updated = updated



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReadingDelete(Model):
    """ReadingDelete.

    :param channel_id: The identifier for the channel of the reading <span
     class='property-internal'>Required</span>
    :type channel_id: int
    :param time_begin: The begin date and time of the set of readings to be
     deleted.
     If provided, readings after but NOT including the provided begin date and
     time will be deleted.
    :type time_begin: datetime
    :param time_end: The end date and time of the set of readings to be
     deleted.
     If provided, readings up to and including the provided end date and time
     will be deleted.
    :type time_end: datetime
    """

    _validation = {
        'channel_id': {'required': True},
    }

    _attribute_map = {
        'channel_id': {'key': 'channelId', 'type': 'int'},
        'time_begin': {'key': 'timeBegin', 'type': 'iso-8601'},
        'time_end': {'key': 'timeEnd', 'type': 'iso-8601'},
    }

    def __init__(self, channel_id, time_begin=None, time_end=None):
        super(ReadingDelete, self).__init__()
        self.channel_id = channel_id
        self.time_begin = time_begin
        self.time_end = time_end



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WeatherStationChild(Model):
    """WeatherStationChild.

    :param station_id:
    :type station_id: int
    :param station_code:  <span class='property-internal'>Required</span>
     <span class='property-internal'>Must be between 0 and 6 characters</span>
    :type station_code: str
    :param station_info:  <span class='property-internal'>Must be between 0
     and 64 characters</span>
    :type station_info: str
    :param city:  <span class='property-internal'>Must be between 0 and 32
     characters</span>
    :type city: str
    :param state:  <span class='property-internal'>Must be between 0 and 32
     characters</span>
    :type state: str
    :param country:  <span class='property-internal'>Must be between 0 and 32
     characters</span>
    :type country: str
    """

    _validation = {
        'station_code': {'required': True, 'max_length': 6, 'min_length': 0},
        'station_info': {'max_length': 64, 'min_length': 0},
        'city': {'max_length': 32, 'min_length': 0},
        'state': {'max_length': 32, 'min_length': 0},
        'country': {'max_length': 32, 'min_length': 0},
    }

    _attribute_map = {
        'station_id': {'key': 'stationId', 'type': 'int'},
        'station_code': {'key': 'stationCode', 'type': 'str'},
        'station_info': {'key': 'stationInfo', 'type': 'str'},
        'city': {'key': 'city', 'type': 'str'},
        'state': {'key': 'state', 'type': 'str'},
        'country': {'key': 'country', 'type': 'str'},
    }

    def __init__(self, station_code, station_id=None, station_info=None, city=None, state=None, country=None):
        super(WeatherStationChild, self).__init__()
        self.station_id = station_id
        self.station_code = station_code
        self.station_info = station_info
        self.city = city
        self.state = state
        self.country = country



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FlagEdit(Model):
    """FlagEdit.

    :param flag_type_id: Type of the flag
    :type flag_type_id: int
    :param flag_status_id: Current status of the flag <span
     class='property-internal'>One of 1, 2 </span>
    :type flag_status_id: int
    :param cost_recovery: Cost recovery associated with the issue this flag
     represents
    :type cost_recovery: float
    :param comment: Event and action that has occured with this flag
    :type comment: str
    :param assignees: All users currently assigned to this flag
    :type assignees: list[int]
    :param release_export_hold: If entity is being held from export, release
     it?
    :type release_export_hold: bool
    """

    _attribute_map = {
        'flag_type_id': {'key': 'flagTypeId', 'type': 'int'},
        'flag_status_id': {'key': 'flagStatusId', 'type': 'int'},
        'cost_recovery': {'key': 'costRecovery', 'type': 'float'},
        'comment': {'key': 'comment', 'type': 'str'},
        'assignees': {'key': 'assignees', 'type': '[int]'},
        'release_export_hold': {'key': 'releaseExportHold', 'type': 'bool'},
    }

    def __init__(self, flag_type_id=None, flag_status_id=None, cost_recovery=None, comment=None, assignees=None, release_export_hold=None):
        super(FlagEdit, self).__init__()
        self.flag_type_id = flag_type_id
        self.flag_status_id = flag_status_id
        self.cost_recovery = cost_recovery
        self.comment = comment
        self.assignees = assignees
        self.release_export_hold = release_export_hold



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceGroupChild(Model):
    """PlaceGroupChild.

    :param place_group_id: The place group identifier
    :type place_group_id: int
    :param place_group_code: The place group code
    :type place_group_code: str
    :param place_group_info: The place group info
    :type place_group_info: str
    :param auto_group: Indicates if this place group is an autogroup
    :type auto_group: bool
    :param user_defined_auto_group: Indicates if this place group is an user
     defined auto group
    :type user_defined_auto_group: bool
    """

    _attribute_map = {
        'place_group_id': {'key': 'placeGroupId', 'type': 'int'},
        'place_group_code': {'key': 'placeGroupCode', 'type': 'str'},
        'place_group_info': {'key': 'placeGroupInfo', 'type': 'str'},
        'auto_group': {'key': 'autoGroup', 'type': 'bool'},
        'user_defined_auto_group': {'key': 'userDefinedAutoGroup', 'type': 'bool'},
    }

    def __init__(self, place_group_id=None, place_group_code=None, place_group_info=None, auto_group=None, user_defined_auto_group=None):
        super(PlaceGroupChild, self).__init__()
        self.place_group_id = place_group_id
        self.place_group_code = place_group_code
        self.place_group_info = place_group_info
        self.auto_group = auto_group
        self.user_defined_auto_group = user_defined_auto_group



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FlagResponse(Model):
    """FlagResponse.

    :param flag_id: The flag identifier
    :type flag_id: int
    :param flag_type: Type of the flag
    :type flag_type: ~energycap.sdk.models.FlagTypeChild
    :param flag_status: Current status of the flag
    :type flag_status: ~energycap.sdk.models.FlagStatusChild
    :param created_by: User that created the flag
    :type created_by: ~energycap.sdk.models.UserChild
    :param created_date: Date the flag was created
    :type created_date: datetime
    :param modified_by: Last user that modified the flag
    :type modified_by: ~energycap.sdk.models.UserChild
    :param modified_date: Latest date the flag was modified
    :type modified_date: datetime
    :param cost_recovery: Cost recovery associated with the issue this flag
     represents
    :type cost_recovery: float
    :param flag_events: All events and actions that have occured with this
     flag
    :type flag_events: list[~energycap.sdk.models.FlagEventChild]
    :param assignees: All users currently assigned to this flag
    :type assignees: list[~energycap.sdk.models.UserChild]
    """

    _attribute_map = {
        'flag_id': {'key': 'flagId', 'type': 'int'},
        'flag_type': {'key': 'flagType', 'type': 'FlagTypeChild'},
        'flag_status': {'key': 'flagStatus', 'type': 'FlagStatusChild'},
        'created_by': {'key': 'createdBy', 'type': 'UserChild'},
        'created_date': {'key': 'createdDate', 'type': 'iso-8601'},
        'modified_by': {'key': 'modifiedBy', 'type': 'UserChild'},
        'modified_date': {'key': 'modifiedDate', 'type': 'iso-8601'},
        'cost_recovery': {'key': 'costRecovery', 'type': 'float'},
        'flag_events': {'key': 'flagEvents', 'type': '[FlagEventChild]'},
        'assignees': {'key': 'assignees', 'type': '[UserChild]'},
    }

    def __init__(self, flag_id=None, flag_type=None, flag_status=None, created_by=None, created_date=None, modified_by=None, modified_date=None, cost_recovery=None, flag_events=None, assignees=None):
        super(FlagResponse, self).__init__()
        self.flag_id = flag_id
        self.flag_type = flag_type
        self.flag_status = flag_status
        self.created_by = created_by
        self.created_date = created_date
        self.modified_by = modified_by
        self.modified_date = modified_date
        self.cost_recovery = cost_recovery
        self.flag_events = flag_events
        self.assignees = assignees



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SystemUserRoleRequest(Model):
    """SystemUserRoleRequest.

    :param system_user_role_name:  <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 64 characters</span>
    :type system_user_role_name: str
    :param description:  <span class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 1000 characters</span>
    :type description: str
    :param permissions:
    :type permissions: ~energycap.sdk.models.PermissionsRequest
    """

    _validation = {
        'system_user_role_name': {'required': True, 'max_length': 64, 'min_length': 0},
        'description': {'required': True, 'max_length': 1000, 'min_length': 0},
    }

    _attribute_map = {
        'system_user_role_name': {'key': 'systemUserRoleName', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'permissions': {'key': 'permissions', 'type': 'PermissionsRequest'},
    }

    def __init__(self, system_user_role_name, description, permissions=None):
        super(SystemUserRoleRequest, self).__init__()
        self.system_user_role_name = system_user_role_name
        self.description = description
        self.permissions = permissions



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SumRequest(Model):
    """<span class='property-internal'>Only one of SumMeterIds, SumMeterGroupIds
    is required</span>.

    :param sum_meter_ids: Meters in this list will have their use or cost
     added together during the bill calculation
    :type sum_meter_ids: list[int]
    :param sum_meter_group_ids: Distinct meters from these meter groups will
     have their use or cost added together during the bill calculation
     System auto groups cannot be used
    :type sum_meter_group_ids: list[int]
    """

    _attribute_map = {
        'sum_meter_ids': {'key': 'sumMeterIds', 'type': '[int]'},
        'sum_meter_group_ids': {'key': 'sumMeterGroupIds', 'type': '[int]'},
    }

    def __init__(self, sum_meter_ids=None, sum_meter_group_ids=None):
        super(SumRequest, self).__init__()
        self.sum_meter_ids = sum_meter_ids
        self.sum_meter_group_ids = sum_meter_group_ids



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillHeaderUpdateAccountPeriodChild(Model):
    """Account Period.

    :param account_period:  <span class='property-internal'>Must be between
     190001 and 209913</span>
    :type account_period: int
    :param update: Indicates whether or not the header value is being updated
     <span class='property-internal'>Required</span>
    :type update: bool
    """

    _validation = {
        'account_period': {'maximum': 209913, 'minimum': 190001},
        'update': {'required': True},
    }

    _attribute_map = {
        'account_period': {'key': 'accountPeriod', 'type': 'int'},
        'update': {'key': 'update', 'type': 'bool'},
    }

    def __init__(self, update, account_period=None):
        super(BillHeaderUpdateAccountPeriodChild, self).__init__()
        self.account_period = account_period
        self.update = update



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterTypeChild(Model):
    """MeterTypeChild.

    :param meter_type_id:
    :type meter_type_id: int
    :param meter_type_code:
    :type meter_type_code: str
    :param meter_type_info:
    :type meter_type_info: str
    """

    _attribute_map = {
        'meter_type_id': {'key': 'meterTypeId', 'type': 'int'},
        'meter_type_code': {'key': 'meterTypeCode', 'type': 'str'},
        'meter_type_info': {'key': 'meterTypeInfo', 'type': 'str'},
    }

    def __init__(self, meter_type_id=None, meter_type_code=None, meter_type_info=None):
        super(MeterTypeChild, self).__init__()
        self.meter_type_id = meter_type_id
        self.meter_type_code = meter_type_code
        self.meter_type_info = meter_type_info



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillingPeriodUseCostDeltaChild(Model):
    """BillingPeriodUseCostDeltaChild.

    :param billing_period: The billing period that the data represents.
     Will be the current billing period, the same year prior billing period,
     or the same period prior year billing period.
    :type billing_period: int
    :param use: The total common use for the specified billing period, and the
     change from this billing period to the current billing period.
     Will be null if there is no use (i.e. supplier meter) in the period.
    :type use: ~energycap.sdk.models.BillingPeriodUseUnitDeltaChild
    :param cost: The total cost for the specified billing period, and the
     change from this billing period to the current billing period.
    :type cost: ~energycap.sdk.models.BillingPeriodCostUnitDeltaChild
    """

    _attribute_map = {
        'billing_period': {'key': 'billingPeriod', 'type': 'int'},
        'use': {'key': 'use', 'type': 'BillingPeriodUseUnitDeltaChild'},
        'cost': {'key': 'cost', 'type': 'BillingPeriodCostUnitDeltaChild'},
    }

    def __init__(self, billing_period=None, use=None, cost=None):
        super(BillingPeriodUseCostDeltaChild, self).__init__()
        self.billing_period = billing_period
        self.use = use
        self.cost = cost



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillEntryResponse(Model):
    """BillEntryResponse.

    :param bill_id: The bill identifier
    :type bill_id: int
    :param account_id: The account identifier
    :type account_id: int
    :param vendor_id: The vendor identifier
    :type vendor_id: int
    :param needs_to_open_batch: Indicates if a new bill batch needs to be
     opened to place this bill in
    :type needs_to_open_batch: bool
    :param begin_date: The bill's begin date
    :type begin_date: datetime
    :param end_date: The bill's end date
    :type end_date: datetime
    :param billing_period: The bill's billing period
    :type billing_period: int
    :param days: The bill's number of days
    :type days: int
    :param total_cost: The bill's total cost
    :type total_cost: float
    :param due_date: The bill's due date
    :type due_date: ~energycap.sdk.models.BillHeaderChild
    :param statement_date: The date of the billing statement
    :type statement_date: ~energycap.sdk.models.BillHeaderChild
    :param invoice_number: The bill's invoice number
    :type invoice_number: ~energycap.sdk.models.BillHeaderChild
    :param control_code: The bill's control code
    :type control_code: ~energycap.sdk.models.BillHeaderChild
    :param next_reading: The bill's next reading date
    :type next_reading: ~energycap.sdk.models.BillHeaderChild
    :param account_period_name: The bill's accounting period name
    :type account_period_name: ~energycap.sdk.models.BillHeaderChild
    :param account_period_number: The bill's accounting period
    :type account_period_number: ~energycap.sdk.models.BillHeaderChild
    :param account_period_year: The bill's accounting period year
    :type account_period_year: ~energycap.sdk.models.BillHeaderChild
    :param estimated: Indicates if the bill is estimated
    :type estimated: ~energycap.sdk.models.BillHeaderChild
    :param bill_note: The bill's note
    :type bill_note: str
    :param void: Indicates if the bill has been voided
    :type void: bool
    :param from_vendor: Indicates if the bill is from a vendor
    :type from_vendor: bool
    :param observation_method: The bill's observation method
    :type observation_method: ~energycap.sdk.models.ObservationMethodChild
    :param approved: Indicates if the bill has been approved
    :type approved: bool
    :param has_been_split: Indicates if the bill has been split
    :type has_been_split: bool
    :param export_hold: Indicates if the bill is being withheld from bill
     exports
    :type export_hold: bool
    :param ap_exported: Indicates if the bill has been ap exported
    :type ap_exported: bool
    :param gl_exported: Indicates if the bill has been gl exported
    :type gl_exported: bool
    :param accrual: Indicates if the bill is an accrual bill
    :type accrual: bool
    :param check_number: The number of the check that the bill was paid with
    :type check_number: str
    :param check_date: The date and time of the check
    :type check_date: datetime
    :param pay_status: The payment status of the bill
    :type pay_status: str
    :param cleared_date: The date and time that the check cleared
    :type cleared_date: datetime
    :param bill_image_url: The fully qualified url to the bill image
    :type bill_image_url: str
    :param general_ledger_code: The general ledger code of the bill's
     account-level details ("Mixed" if there is more than one)
    :type general_ledger_code: str
    :param meters: The billing account's meters
    :type meters: list[~energycap.sdk.models.BillEntryMeterChild]
    :param account_body_lines: The bill's account-level details
    :type account_body_lines: list[~energycap.sdk.models.BillEntryBodyLine]
    """

    _attribute_map = {
        'bill_id': {'key': 'billId', 'type': 'int'},
        'account_id': {'key': 'accountId', 'type': 'int'},
        'vendor_id': {'key': 'vendorId', 'type': 'int'},
        'needs_to_open_batch': {'key': 'needsToOpenBatch', 'type': 'bool'},
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'billing_period': {'key': 'billingPeriod', 'type': 'int'},
        'days': {'key': 'days', 'type': 'int'},
        'total_cost': {'key': 'totalCost', 'type': 'float'},
        'due_date': {'key': 'dueDate', 'type': 'BillHeaderChild'},
        'statement_date': {'key': 'statementDate', 'type': 'BillHeaderChild'},
        'invoice_number': {'key': 'invoiceNumber', 'type': 'BillHeaderChild'},
        'control_code': {'key': 'controlCode', 'type': 'BillHeaderChild'},
        'next_reading': {'key': 'nextReading', 'type': 'BillHeaderChild'},
        'account_period_name': {'key': 'accountPeriodName', 'type': 'BillHeaderChild'},
        'account_period_number': {'key': 'accountPeriodNumber', 'type': 'BillHeaderChild'},
        'account_period_year': {'key': 'accountPeriodYear', 'type': 'BillHeaderChild'},
        'estimated': {'key': 'estimated', 'type': 'BillHeaderChild'},
        'bill_note': {'key': 'billNote', 'type': 'str'},
        'void': {'key': 'void', 'type': 'bool'},
        'from_vendor': {'key': 'fromVendor', 'type': 'bool'},
        'observation_method': {'key': 'observationMethod', 'type': 'ObservationMethodChild'},
        'approved': {'key': 'approved', 'type': 'bool'},
        'has_been_split': {'key': 'hasBeenSplit', 'type': 'bool'},
        'export_hold': {'key': 'exportHold', 'type': 'bool'},
        'ap_exported': {'key': 'apExported', 'type': 'bool'},
        'gl_exported': {'key': 'glExported', 'type': 'bool'},
        'accrual': {'key': 'accrual', 'type': 'bool'},
        'check_number': {'key': 'checkNumber', 'type': 'str'},
        'check_date': {'key': 'checkDate', 'type': 'iso-8601'},
        'pay_status': {'key': 'payStatus', 'type': 'str'},
        'cleared_date': {'key': 'clearedDate', 'type': 'iso-8601'},
        'bill_image_url': {'key': 'billImageUrl', 'type': 'str'},
        'general_ledger_code': {'key': 'generalLedgerCode', 'type': 'str'},
        'meters': {'key': 'meters', 'type': '[BillEntryMeterChild]'},
        'account_body_lines': {'key': 'accountBodyLines', 'type': '[BillEntryBodyLine]'},
    }

    def __init__(self, bill_id=None, account_id=None, vendor_id=None, needs_to_open_batch=None, begin_date=None, end_date=None, billing_period=None, days=None, total_cost=None, due_date=None, statement_date=None, invoice_number=None, control_code=None, next_reading=None, account_period_name=None, account_period_number=None, account_period_year=None, estimated=None, bill_note=None, void=None, from_vendor=None, observation_method=None, approved=None, has_been_split=None, export_hold=None, ap_exported=None, gl_exported=None, accrual=None, check_number=None, check_date=None, pay_status=None, cleared_date=None, bill_image_url=None, general_ledger_code=None, meters=None, account_body_lines=None):
        super(BillEntryResponse, self).__init__()
        self.bill_id = bill_id
        self.account_id = account_id
        self.vendor_id = vendor_id
        self.needs_to_open_batch = needs_to_open_batch
        self.begin_date = begin_date
        self.end_date = end_date
        self.billing_period = billing_period
        self.days = days
        self.total_cost = total_cost
        self.due_date = due_date
        self.statement_date = statement_date
        self.invoice_number = invoice_number
        self.control_code = control_code
        self.next_reading = next_reading
        self.account_period_name = account_period_name
        self.account_period_number = account_period_number
        self.account_period_year = account_period_year
        self.estimated = estimated
        self.bill_note = bill_note
        self.void = void
        self.from_vendor = from_vendor
        self.observation_method = observation_method
        self.approved = approved
        self.has_been_split = has_been_split
        self.export_hold = export_hold
        self.ap_exported = ap_exported
        self.gl_exported = gl_exported
        self.accrual = accrual
        self.check_number = check_number
        self.check_date = check_date
        self.pay_status = pay_status
        self.cleared_date = cleared_date
        self.bill_image_url = bill_image_url
        self.general_ledger_code = general_ledger_code
        self.meters = meters
        self.account_body_lines = account_body_lines



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WeatherStationResponse(Model):
    """WeatherStationResponse.

    :param station_id: ID of the weather station
    :type station_id: int
    :param station_code: Weather station code
    :type station_code: str
    :param station_info: Weather station info
    :type station_info: str
    :param base_station_code: Code of the base weather station
     Will be null if not linked
    :type base_station_code: str
    :param channel: The channel containing the weather station's mean daily
     temperature
    :type channel: ~energycap.sdk.models.ChannelChild
    """

    _attribute_map = {
        'station_id': {'key': 'stationId', 'type': 'int'},
        'station_code': {'key': 'stationCode', 'type': 'str'},
        'station_info': {'key': 'stationInfo', 'type': 'str'},
        'base_station_code': {'key': 'baseStationCode', 'type': 'str'},
        'channel': {'key': 'channel', 'type': 'ChannelChild'},
    }

    def __init__(self, station_id=None, station_code=None, station_info=None, base_station_code=None, channel=None):
        super(WeatherStationResponse, self).__init__()
        self.station_id = station_id
        self.station_code = station_code
        self.station_info = station_info
        self.base_station_code = base_station_code
        self.channel = channel



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BatchEdit(Model):
    """BatchEdit.

    :param batch_code: The batch code <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 255 characters</span>
    :type batch_code: str
    :param note: Note/comment for batch <span class='property-internal'>Must
     be between 0 and 255 characters</span>
    :type note: str
    """

    _validation = {
        'batch_code': {'required': True, 'max_length': 255, 'min_length': 0},
        'note': {'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'batch_code': {'key': 'batchCode', 'type': 'str'},
        'note': {'key': 'note', 'type': 'str'},
    }

    def __init__(self, batch_code, note=None):
        super(BatchEdit, self).__init__()
        self.batch_code = batch_code
        self.note = note



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestGHGYearlyResponseTargetComparison(Model):
    """PlaceDigestGHGYearlyResponseTargetComparison.

    :param target_year: Target year
    :type target_year: int
    :param target_label: Target label
    :type target_label: str
    :param equivalent_co2_emissions: Equivalent CO2 emissions for the target
     year
    :type equivalent_co2_emissions: float
    :param equivalent_co2_emissions_ytd: Equivalent CO2 emissions for the
     target year up to the target period that corresponds to the current period
    :type equivalent_co2_emissions_ytd: float
    """

    _attribute_map = {
        'target_year': {'key': 'targetYear', 'type': 'int'},
        'target_label': {'key': 'targetLabel', 'type': 'str'},
        'equivalent_co2_emissions': {'key': 'equivalentCO2Emissions', 'type': 'float'},
        'equivalent_co2_emissions_ytd': {'key': 'equivalentCO2EmissionsYtd', 'type': 'float'},
    }

    def __init__(self, target_year=None, target_label=None, equivalent_co2_emissions=None, equivalent_co2_emissions_ytd=None):
        super(PlaceDigestGHGYearlyResponseTargetComparison, self).__init__()
        self.target_year = target_year
        self.target_label = target_label
        self.equivalent_co2_emissions = equivalent_co2_emissions
        self.equivalent_co2_emissions_ytd = equivalent_co2_emissions_ytd



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FileContentResult(Model):
    """FileContentResult.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :param file_contents:
    :type file_contents: bytearray
    :ivar content_type:
    :vartype content_type: str
    :param file_download_name:
    :type file_download_name: str
    :param last_modified:
    :type last_modified: datetime
    :param entity_tag:
    :type entity_tag: ~energycap.sdk.models.EntityTagHeaderValue
    :param enable_range_processing:
    :type enable_range_processing: bool
    """

    _validation = {
        'content_type': {'readonly': True},
    }

    _attribute_map = {
        'file_contents': {'key': 'fileContents', 'type': 'bytearray'},
        'content_type': {'key': 'contentType', 'type': 'str'},
        'file_download_name': {'key': 'fileDownloadName', 'type': 'str'},
        'last_modified': {'key': 'lastModified', 'type': 'iso-8601'},
        'entity_tag': {'key': 'entityTag', 'type': 'EntityTagHeaderValue'},
        'enable_range_processing': {'key': 'enableRangeProcessing', 'type': 'bool'},
    }

    def __init__(self, file_contents=None, file_download_name=None, last_modified=None, entity_tag=None, enable_range_processing=None):
        super(FileContentResult, self).__init__()
        self.file_contents = file_contents
        self.content_type = None
        self.file_download_name = file_download_name
        self.last_modified = last_modified
        self.entity_tag = entity_tag
        self.enable_range_processing = enable_range_processing



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AucRangeRequest(Model):
    """AucRangeRequest.

    :param commodity_id: The unique identifier for the commodity
    :type commodity_id: int
    :param lower_limit_multiplier: When the current bill's average unit cost
     is LOWER than this multiplier x the baseline bill's average unit cost,
     then the cost avoidance processor will use the average unit cost from the
     baseline bill instead of the current bill <span
     class='property-internal'>Must be between 0.1 and 20.0</span>
    :type lower_limit_multiplier: float
    :param upper_limit_multiplier: When the current bill's average unit cost
     is HIGHER than this multiplier x the baseline bill's average unit cost,
     then the cost avoidance processor will use the average unit cost from the
     baseline bill instead of the current bill <span
     class='property-internal'>Must be between 0.1 and 20.0</span>
    :type upper_limit_multiplier: float
    """

    _validation = {
        'lower_limit_multiplier': {'maximum': 20, 'minimum': 0.1},
        'upper_limit_multiplier': {'maximum': 20, 'minimum': 0.1},
    }

    _attribute_map = {
        'commodity_id': {'key': 'commodityId', 'type': 'int'},
        'lower_limit_multiplier': {'key': 'lowerLimitMultiplier', 'type': 'float'},
        'upper_limit_multiplier': {'key': 'upperLimitMultiplier', 'type': 'float'},
    }

    def __init__(self, commodity_id=None, lower_limit_multiplier=None, upper_limit_multiplier=None):
        super(AucRangeRequest, self).__init__()
        self.commodity_id = commodity_id
        self.lower_limit_multiplier = lower_limit_multiplier
        self.upper_limit_multiplier = upper_limit_multiplier
